'use strict';

function _interopDefault (ex) { return (ex && (typeof ex === 'object') && 'default' in ex) ? ex['default'] : ex; }

var _defineProperty = _interopDefault(require('@babel/runtime/helpers/defineProperty'));

/**
 * Transformer are used to change format of locale (eg. convert it to uppercase), create fallbacks or delete invalid items.
 */
class Transformer {}

/**
 * This transformer allows you to filter locales
 */

class AllowOnlyTransformer extends Transformer {
  /**
   * Constructor.
   *
   * @param {Array<string>} allowedLocales - list of allowed locales
   */
  constructor(allowedLocales) {
    super();

    _defineProperty(this, "allowedLocales", void 0);

    this.allowedLocales = allowedLocales;
  }
  /**
   * Return only allowed locales.
   *
   * @param {Array<string>} locales - list of locales
   * @returns {Array<string>} allowed locales
   */


  transform(locales) {
    return locales.filter(locale => {
      return this.allowedLocales.includes(locale);
    });
  }

}

module.exports = AllowOnlyTransformer;
